==> owncloud-10.0.8.tar.bz2: owncloud/core/l10n/es_AR.js <==
OC.L10N.register(
    "core",
    {
    "No image or file provided" : "No se ha proveído de una imágen o archivo.",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay una imágen temporal del perfil disponible, intente de nuevo",
    "No crop data provided" : "No se proveyeron datos de recorte",
    "%s password reset" : "%s restablecer contraseña",
    "Couldn't send mail to following users: %s " : "No se pudieron mandar correos a los siguientes usuarios: %s",
    "Turned on maintenance mode" : "Modo de mantenimiento activado",
    "Turned off maintenance mode" : "Modo de mantenimiento desactivado",
    "Updated database" : "Base de datos actualizada",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "dom.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "miér.",
    "Thu." : "jue.",
    "Fri." : "vie.",
    "Sat." : "sáb.",
    "January" : "enero",
    "February" : "febrero",
    "March" : "marzo",
    "April" : "abril",
    "May" : "mayo",
    "June" : "junio",
    "July" : "julio",
    "August" : "agosto",
    "September" : "septiembre",
    "October" : "octubre",
    "November" : "noviembre",
    "December" : "diciembre",
    "Jan." : "ene.",
    "Feb." : "feb.",
    "Mar." : "mar.",
    "Apr." : "abr.",
    "May." : "may.",
    "Jun." : "jun.",
    "Jul." : "jul.",
    "Aug." : "ago.",
    "Sep." : "sep.",
    "Oct." : "oct.",
    "Nov." : "nov.",
    "Dec." : "dic.",
    "Settings" : "Configuración",
    "Saving..." : "Guardando...",
    "seconds ago" : "segundos atrás",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Elegir",
    "Error loading file picker template: {error}" : "Error cargando la plantilla del selector de archivo: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error cargando la plantilla del mensaje: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["un archivo en conflicto","{count} archivos en conflicto"],
    "One file conflict" : "Un archivo en conflicto",
    "New Files" : "Nuevos archivos",
    "Which files do you want to keep?" : "¿Qué archivos deseas retener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si tu seleccionas ambas versiones, el archivo copiado tendrá un número agregado a su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos están seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando la plantilla de archivo existente",
    "Very weak password" : "Contraseña muy débil.",
    "Weak password" : "Contraseña débil.",
    "So-so password" : "Contraseña de nivel medio. ",
    "Good password" : "Buena contraseña. ",
    "Strong password" : "Contraseña fuerte.",
    "Shared" : "Compartido",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error en al dejar de compartir",
    "Set expiration date" : "Asignar fecha de vencimiento",
    "Expiration" : "Vencimiento",
    "Expiration date" : "Fecha de vencimiento",
    "Edit" : "Editar",
    "Remove" : "Borrar",
    "Password" : "Contraseña",
    "Name" : "Nombre",
    "Save" : "Guardar",
    "Sending ..." : "Mandando...",
    "Email sent" : "e-mail mandado",
    "Email link to person" : "Enviar el enlace por e-mail.",
    "Shared with you and the group {group} by {owner}" : "Compartido con vos y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido con vos por {owner}",
    "group" : "grupo",
    "notify by email" : "notificar por correo",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "podés editar",
    "create" : "crear",
    "delete" : "borrar",
    "access control" : "control de acceso",
    "Share" : "Compartir",
    "Resharing is not allowed" : "No se permite volver a compartir",
    "Warning" : "Atención",
    "Delete" : "Borrar",
    "Rename" : "Cambiar nombre",
    "The object type is not specified." : "El tipo de objeto no está especificado. ",
    "Enter new" : "Entrar nuevo",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error cargando la plantilla de dialogo: {error}",
    "No tags selected for deletion." : "No se han seleccionado etiquetas para eliminar.",
    "Please reload the page." : "Por favor, recargue la página.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "La actualización no pudo ser completada. Por favor, reportá el inconveniente a la comunidad <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización fue exitosa. Estás siendo redirigido a ownCloud.",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Apps",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso prohibido",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "¡Hola!\n\nsólo te quería decir que %s acaba de compartir %s contigo.\nVerlo: %s\n\n",
    "The share will expire on %s." : "El compartir expirará en %s.",
    "Cheers!" : "¡Saludos!",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Data folder" : "Directorio de almacenamiento",
    "Configure the database" : "Configurar la base de datos",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Huésped de la base de datos",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando...",
    "Log out" : "Cerrar la sesión",
    "Search" : "Buscar",
    "Server side authentication failed!" : "¡Falló la autenticación del servidor!",
    "Please contact your administrator." : "Por favor, contacte a su administrador.",
    "Log in" : "Iniciar sesión",
    "Alternative Logins" : "Nombre alternativos de usuarios",
    "Use the following link to reset your password: {link}" : "Usá este enlace para restablecer tu contraseña: {link}",
    "New password" : "Nueva contraseña:",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instancia de ownCloud está en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto significa que solo administradores pueden usar esta instancia.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte su administrador de sistema si este mensaje persiste o aparece inesperadamente.",
    "Thank you for your patience." : "Gracias por su paciencia.",
    "Remove link" : "Eliminar enlace",
    "Link" : "Enlace",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Filename" : "Nombre de archivo",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección Remota: %s",
    "Request ID: %s" : "ID requiriente: %s",
    "File is too big" : "El archivo es demasiado grande",
    "Please select a file." : "Por favor seleccione un archivo."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.7.0.tar.bz2: owncloud/core/l10n/es_AR.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor seleccione un archivo.",
    "File is too big" : "El archivo es demasiado grande",
    "No image or file provided" : "No se ha proveído de una imágen o archivo.",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay una imágen temporal del perfil disponible, intente de nuevo",
    "No crop data provided" : "No se proveyeron datos de recorte",
    "%s password changed successfully" : "%s contraseña actualizada satisfactoriamente",
    "%s password reset" : "%s restablecer contraseña",
    "Couldn't send reset email. Please contact your administrator." : "No se puede enviar el correo para reestablecer. Por favor contacte al administrador.",
    "Download / View" : "Descargar / Ver",
    "Download / View / Upload" : "Descargar / Ver / Subir",
    "Turned on maintenance mode" : "Modo de mantenimiento activado",
    "Turned off maintenance mode" : "Modo de mantenimiento desactivado",
    "Updated database" : "Base de datos actualizada",
    "Checked database schema update" : "Actualización del esquema de base de datos chequeado",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "dom.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "miér.",
    "Thu." : "jue.",
    "Fri." : "vie.",
    "Sat." : "sáb.",
    "January" : "enero",
    "February" : "febrero",
    "March" : "marzo",
    "April" : "abril",
    "May" : "mayo",
    "June" : "junio",
    "July" : "julio",
    "August" : "agosto",
    "September" : "septiembre",
    "October" : "octubre",
    "November" : "noviembre",
    "December" : "diciembre",
    "Jan." : "ene.",
    "Feb." : "feb.",
    "Mar." : "mar.",
    "Apr." : "abr.",
    "May." : "may.",
    "Jun." : "jun.",
    "Jul." : "jul.",
    "Aug." : "ago.",
    "Sep." : "sep.",
    "Oct." : "oct.",
    "Nov." : "nov.",
    "Dec." : "dic.",
    "Settings" : "Configuración",
    "Saving..." : "Guardando...",
    "seconds ago" : "segundos atrás",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "El enlace para restablecer la contraseña fue enviada a tu e-mail. <br> Si no lo recibís en un plazo de tiempo razonable,  revisá tu carpeta de spam / correo no deseado. <br> Si no está ahí, preguntale a tu administrador.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tus archivos están encriptados. Si no habilitaste la clave de recuperación, no vas a tener manera de obtener nuevamente tus datos después que se restablezca tu contraseña. Si no estás seguro sobre qué hacer, ponete en contacto con el administrador antes de seguir. ¿Estás seguro/a que querés continuar?",
    "I know what I'm doing" : "Sé lo que estoy haciendo",
    "Password can not be changed. Please contact your administrator." : "La contraseña no puede ser cambiada. Por favor contacte al administrador.",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Elegir",
    "Error loading file picker template: {error}" : "Error cargando la plantilla del selector de archivo: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error cargando la plantilla del mensaje: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["un archivo en conflicto","{count} archivos en conflicto"],
    "One file conflict" : "Un archivo en conflicto",
    "New Files" : "Nuevos archivos",
    "Already existing files" : "Archivos ya existentes",
    "Which files do you want to keep?" : "¿Qué archivos deseas retener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si tu seleccionas ambas versiones, el archivo copiado tendrá un número agregado a su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos están seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando la plantilla de archivo existente",
    "Very weak password" : "Contraseña muy débil.",
    "Weak password" : "Contraseña débil.",
    "So-so password" : "Contraseña de nivel medio. ",
    "Good password" : "Buena contraseña. ",
    "Strong password" : "Contraseña fuerte.",
    "Shared" : "Compartido",
    "Shared with {recipients}" : "Compartido con {recipients}",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error en al dejar de compartir",
    "The public link will expire no later than {days} days after it is created" : "El enlace público expirará no antes de {days} días después de su creación",
    "Expiration" : "Vencimiento",
    "Remove link" : "Eliminar enlace",
    "Link" : "Enlace",
    "Edit" : "Editar",
    "Remove" : "Borrar",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Anyone with the link has access to the file/folder" : "Cualquiera que tenga acceso al enlace del archivo/carpeta",
    "Link name" : "Nombre de enlace",
    "Name" : "Nombre",
    "Filename" : "Nombre de archivo",
    "Password" : "Contraseña",
    "Share" : "Compartir",
    "Save" : "Guardar",
    "Email link to person" : "Enviar el enlace por e-mail.",
    "Shared with you and the group {group} by {owner}" : "Compartido con vos y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido con vos por {owner}",
    "group" : "grupo",
    "notify by email" : "notificar por correo",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "podés editar",
    "create" : "crear",
    "change" : "cambiar",
    "delete" : "borrar",
    "access control" : "control de acceso",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartir con personas en otras instancias de OwnCloud utilizando la sintaxis username@example.com/owncloud",
    "Delete" : "Borrar",
    "Rename" : "Cambiar nombre",
    "The object type is not specified." : "El tipo de objeto no está especificado. ",
    "Enter new" : "Entrar nuevo",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error cargando la plantilla de dialogo: {error}",
    "No tags selected for deletion." : "No se han seleccionado etiquetas para eliminar.",
    "Please reload the page." : "Por favor, recargue la página.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "La actualización no pudo ser completada. Por favor, reportá el inconveniente a la comunidad <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización fue exitosa. Estás siendo redirigido a ownCloud.",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Apps",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso prohibido",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "¡Hola!\n\nsólo te quería decir que %s acaba de compartir %s contigo.\nVerlo: %s\n\n",
    "The share will expire on %s." : "El compartir expirará en %s.",
    "Cheers!" : "¡Saludos!",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección Remota: %s",
    "Request ID: %s" : "ID requiriente: %s",
    "Imprint" : "Imprint",
    "Privacy Policy" : "Política de privacidad",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Storage & database" : "Almacenamiento y base de datos",
    "Data folder" : "Directorio de almacenamiento",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Sólo %s está disponible.",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Huésped de la base de datos",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Cuando se utiliza especialmente el cliente de escritorio para la sincronización de archivos, se desaconseja el uso de SQLite.",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando...",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "¡Hola!<br><br> Sólo te quería informar que %s acaba de compartir <strong>%s</strong> con vos.<br><a href=\"%s\">Verlo!</a><br><br>",
    "Log out" : "Cerrar la sesión",
    "Search" : "Buscar",
    "Server side authentication failed!" : "¡Falló la autenticación del servidor!",
    "Please contact your administrator." : "Por favor, contacte a su administrador.",
    "Login" : "Ingresar",
    "Alternative Logins" : "Nombre alternativos de usuarios",
    "Use the following link to reset your password: {link}" : "Usá este enlace para restablecer tu contraseña: {link}",
    "New password" : "Nueva contraseña:",
    "New Password" : "Nueva contraseña",
    "Confirm Password" : "Confirmar contraseña",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instancia de ownCloud está en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto significa que solo administradores pueden usar esta instancia.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte su administrador de sistema si este mensaje persiste o aparece inesperadamente.",
    "Thank you for your patience." : "Gracias por su paciencia.",
    "The theme %s has been disabled." : "El tema %s ha sido deshabilitado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor asegúrate que la base de datos, la carpeta de configuración y la de datos han sido resguardadas antes de proceder.",
    "Start update" : "Comenzar actualización"
},
"nplurals=2; plural=(n != 1);");
